/**
 * @file
 * JavaScript for the Custom Report module.
 *
 * Provides interactive functionality for the custom report tables.
 */

(function ($, Drupal) {
  'use strict';

  /**
   * Behavior for custom report tables.
   *
   * @type {Drupal~behavior}
   *
   * @prop {Drupal~behaviorAttach} attach
   *   Adds zebra striping and mobile responsiveness to report tables.
   */
  Drupal.behaviors.customReport = {
    attach: function (context, settings) {
      // Add zebra striping to tables for better readability.
      $('.custom-report-section table tbody tr:odd', context).addClass('odd');
      $('.custom-report-section table tbody tr:even', context).addClass('even');

      // Make table rows expandable on mobile.
      $('.custom-report-section table', context).once('custom-report').each(function () {
        var $table = $(this);

        // Add click handler for mobile view.
        $table.find('tbody tr').on('click', function () {
          if (window.innerWidth < 768) {
            $(this).toggleClass('expanded');
          }
        });
      });
    }
  };

})(jQuery, Drupal);
